@@ -1,7 +1,7 @@
 from typing import Optional
 
 from ..register import register_ml_module
-from ..protocols.ml import MixedStackedModel
+from ..schemas.ml import MixedStackedModel
 
 
 @register_ml_module("fnet")
